---
id: debian-docker-installieren
title: Docker installieren
sidebar_label: Docker installieren
---

## Einführung
In diesem Tutorial lernst du, wie du Docker auf einem VPS oder Dedicated Server installierst. Die Anleitung enthält sowohl eine distributionsunabhängige Methode als auch eine speziell für Debian 10, 11 und 12 geeignete Variante. Du benötigst Root-Rechte.

Melde dich zunächst als Root-Nutzer mit einem SSH-Client deiner Wahl an, z. B. PuTTY oder Terminus.

## Installation

### 1. Docker installieren (Allgemeine Methode)
Docker kann mit folgendem Einzeiler unabhängig vom Betriebssystem installiert werden:

```sh
curl -sSL https://get.docker.com/ | CHANNEL=stable bash
```

Diese Methode richtet das Repository automatisch ein und installiert die neueste stabile Version von Docker. Sie ist für verschiedene Linux-Distributionen geeignet.

Falls du die manuelle Installation für Debian bevorzugst, folge den nachstehenden Schritten:

### 2. System aktualisieren (Debian-spezifisch)
Führe die folgenden Befehle aus, um dein System auf den neuesten Stand zu bringen:

```sh
apt update && apt upgrade -y
```

### 3. Notwendige Pakete installieren
Installiere die erforderlichen Pakete für die Docker-Installation:

```sh
apt install -y apt-transport-https ca-certificates curl gnupg
```

### 4. Offiziellen GPG-Schlüssel von Docker hinzufügen

```sh
curl -fsSL https://download.docker.com/linux/debian/gpg | gpg --dearmor -o /usr/share/keyrings/docker-archive-keyring.gpg
```

### 5. Docker-Repository hinzufügen

```sh
echo "deb [arch=amd64 signed-by=/usr/share/keyrings/docker-archive-keyring.gpg] https://download.docker.com/linux/debian $(lsb_release -cs) stable" | tee /etc/apt/sources.list.d/docker.list > /dev/null
```

### 6. Docker installieren

```sh
apt update
apt install -y docker-ce docker-ce-cli containerd.io
```

### 7. Überprüfung der Installation
Starte einen Test-Container, um zu überprüfen, ob Docker erfolgreich installiert wurde:

```sh
docker run hello-world
```

Falls die Meldung `Hello from Docker!` erscheint, war die Installation erfolgreich.

## Optional: Docker-Compose installieren

Docker-Compose ist ab **Docker Version 20.10** direkt als `docker compose` integriert. Falls du eine ältere Version nutzt oder die eigenständige `docker-compose`-Binary benötigst, folge den nachstehenden Schritten.

### 1. Docker-Compose herunterladen
Ersetze `2.22.0` durch die neueste verfügbare Version von Docker-Compose:

```sh
VERSION=$(curl -s https://api.github.com/repos/docker/compose/releases/latest | grep "tag_name" | cut -d '"' -f 4)
curl -L "https://github.com/docker/compose/releases/download/$VERSION/docker-compose-$(uname -s)-$(uname -m)" -o /usr/local/bin/docker-compose
```

### 2. Berechtigungen setzen

```sh
chmod +x /usr/local/bin/docker-compose
```

### 3. Falls der Befehl nicht gefunden wird, erstelle einen Softlink

```sh
ln -s /usr/local/bin/docker-compose /usr/bin/docker-compose
```

### 4. Überprüfung der Installation

```sh
docker-compose --version
```

Wenn die Versionsnummer erscheint, war die Installation erfolgreich.

## Abschluss
Docker ist nun installiert und einsatzbereit. Falls du mit Docker-Compose arbeitest, hast du dieses ebenfalls erfolgreich eingerichtet. Nutze Docker für Containerisierung und effizientes Deployment deiner Anwendungen.

### Passenden Server mieten
Falls du noch keinen passenden Server hast, kannst du über folgenden Link einen mieten:
[Root-Server mieten bei DeinServerHost](https://deinserverhost.de/root-server-ssd-mieten)
