---
id: debian-cockpit-installieren
title: Install Cockpit (Debian & Ubuntu)
sidebar_label: Install Cockpit
---
Installation of Cockpit on a Linux Debian or Ubuntu Server

## Information
This tutorial will show you how to install Cockpit on a VPS or Dedicated Server.  
You need a recent version of Debian or Ubuntu and root privileges.  
First, log in as root using your preferred SSH client, such as PuTTY, Terminus, or Tabby.

Before proceeding with the installation, ensure that you have [Sudo](debian-sudo-installieren) installed.

### Supported Versions

Cockpit is available by default in the repositories of:
- **Debian 10, 11, 12** (Buster, Bullseye, Bookworm)
- **Ubuntu 20.04, 22.04, 24.04** (Focal, Jammy, Noble)

---

## Installation

### 1️⃣ Update the package lists:

```sh
sudo apt update && sudo apt upgrade -y
```

### 2️⃣ Install Cockpit:

```sh
sudo apt install cockpit -y
```

### 3️⃣ (Optional) Install additional Cockpit modules:

- **Cockpit Dashboard for multiple servers**
  ```sh
  sudo apt install cockpit-dashboard -y
  ```
- **Storage management module**
  ```sh
  sudo apt install cockpit-storaged -y
  ```
- **Networking tools (Firewall, Network Manager, etc.)**
  ```sh
  sudo apt install cockpit-networkmanager -y
  ```
- **Podman (Docker alternative) integration**
  ```sh
  sudo apt install cockpit-podman -y
  ```
- **Virtual Machines (KVM/QEMU) management**
  ```sh
  sudo apt install cockpit-machines -y
  ```

---

## Starting & Enabling Cockpit

1. Start the Cockpit service:
    ```sh
    sudo systemctl start cockpit
    ```
2. Enable Cockpit to start on boot:
    ```sh
    sudo systemctl enable cockpit
    ```
3. Check the service status:
    ```sh
    sudo systemctl status cockpit
    ```

---

## Accessing Cockpit Web Interface

Once installed, open your browser and navigate to:

```
https://<server-ip>:9090
```

Log in using your system’s root or sudo-enabled user credentials.

> **Note:** If you are using a firewall (e.g., UFW), allow Cockpit's port:
> ```sh
> sudo ufw allow 9090/tcp
> ```

---

## Uninstalling Cockpit

If you want to remove Cockpit completely:

```sh
sudo apt remove --purge cockpit -y
sudo apt autoremove -y
```

Cockpit is now successfully installed and ready to use. ✔
