---
id: valheim-server-erstellen
title: How to Create Your Own Valheim Server!
sidebar_label: Create Valheim Server
---

# Introduction

![Valheim](/img/valheim/valheim_banner.jpg)

Valheim is a survival co-op game. With up to 10 players on a map, you battle monsters, bosses, and gods in a Nordic setting. Right after arriving in Valheim, you are thrown into the deep end – the first few minutes are already quite challenging. Even at the beginning, you’ll encounter wild boars or greylings that aren’t particularly friendly.

So, it's time to gather your first equipment!

The first few minutes might seem a bit underwhelming, but once you craft your first axe, the game truly begins. Throughout the game, you receive tips whenever something new is discovered. When that happens, one of Odin’s ravens, Hugin or Munin, appears with more information.

# Preparation

To run your own Valheim game server, you need a server to host it. Suitable options include vServers, root servers, or dedicated servers. The most important requirement is full administrative control over your system.

Game servers typically require strong single-core performance. This means CPUs with high clock speeds of at least 3.0 GHz. However, I recommend 3.5+ GHz, as a little extra power never hurts.

The operating system doesn't play a major role since Valheim works on both Linux and Windows. However, keep in mind that Windows generally requires more resources. Always allocate additional RAM and storage space.

You can find suitable servers for under €10. I recommend our [KVM Game Servers](https://deinserverhost.de/kvm-vserver-nvme-mieten) with high clock speeds, ideal for game hosting. If you need more power and want a dedicated server, check out our affordable [Dedicated Special Offers](https://deinserverhost.de/store/cart.php?gid=20).

# System Requirements

### **Windows System Requirements**
#### **Client**
Valheim’s system requirements are still evolving in Early Access, but for a good experience, you should have:

- A 64-bit processor and operating system
- Processor: i5 3GHz or better
- RAM: 8 GB (16GB recommended)
- Graphics card: GeForce GTX 970 series or similar
- DirectX: Version 11
- Storage: At least 1 GB of free space

#### **Server**
The system requirements for a Valheim game server are slightly lower, but they depend on the number of simultaneous players. A solid baseline is:

> **⚠️ INFO** - These requirements apply only to the game server. Your vServer or dedicated server should have more resources available.

- A 64-bit processor and operating system
- Processor: At least 3.0 GHz base clock
- RAM: 2 GB (4-8GB recommended)
- Storage: At least 2 GB free (5-10GB recommended)¹

> **⚠️ INFO**  
¹) - uMod or Valheim Plus require additional storage.  
²) - For Linux, ensure driver compatibility by using a modern distribution.

### **Linux System Requirements**
#### **Client**
- A 64-bit processor and operating system
- Processor: i5 3GHz or better
- RAM: 8 GB (16GB recommended)
- Graphics card: GeForce GTX 970 series or similar²
- Storage: At least 1 GB free

#### **Server**
- A 64-bit processor and operating system
- Processor: At least 3.0 GHz base clock
- RAM: 2 GB (4-8GB recommended)
- Storage: At least 2 GB free (5-10GB recommended)¹

---

# Installation

## **Windows Installation**

To install a Valheim server on Windows, follow these steps:

1. Connect to your server via Remote Desktop (RDP).
2. Install **Steam** or **SteamCMD**.
3. Download the Valheim Dedicated Server through Steam or use SteamCMD to install it manually.
4. Configure your server settings.
5. Forward the necessary ports.
6. Start the server and connect using its IP address.

## **Linux Installation**

For Linux servers, the setup process involves:

1. Connecting via SSH using a client like **PuTTY** or **Terminus**.
2. Installing **SteamCMD**.
3. Using **SteamCMD** to download the Valheim Dedicated Server.
4. Configuring server settings in `start_server.sh`.
5. Setting up a **Tmux** session to keep the server running.
6. Opening the necessary ports with **UFW**.
7. Running the server and joining via IP.

For detailed instructions on each step, continue reading below.

---

# **Port Forwarding / Firewall Configuration**

### **Windows Firewall Rules**

Open Windows Firewall and allow the following ports:

- **TCP Ports:** `2456-2457, 27015-27030, 27036-27037`
- **UDP Ports:** `2456-2457, 4380, 27000-27031, 27036`

### **Linux UFW Configuration**

If using **UFW**, allow the same ports with:

```sh
sudo ufw allow 2456:2457,27015:27030,27036:27037/tcp
sudo ufw allow 2456:2457,4380,27000:27031,27036/udp
```

---

# **Joining Your Server**

### **Via In-Game Server Browser**

1. Launch Valheim and go to **Start Game**.
2. Create a character and click **Start**.
3. Use the search bar to find your server.
4. Select it and click **Connect**.
5. Enter the password if required.

### **Via Steam Favorites**

1. Open **Steam** and go to **View > Servers**.
2. Click on **Favorites**.
3. Click **Add a Server** and enter your server’s IP and port.
4. Click **Find Games at this Address**.
5. Add it to favorites and connect.

---

# **Installing uMod**

### **Windows**

```powershell
Invoke-WebRequest https://umod.io/umod-install.ps1 -OutFile umod-install.ps1
./umod-install.ps1
```

### **Linux**

```sh
wget -q https://umod.io/umod-install.sh
chmod +x umod-install.sh
./umod-install.sh
. ~/.profile
```

---

# **Installing Valheim Plus**

### **Windows**
1. Download `WindowsServer.zip` from [Valheim Plus GitHub](https://github.com/valheimPlus/ValheimPlus/releases).
2. Extract it into your Valheim server directory.
3. Start the server.

### **Linux**

```sh
cd /home/Valheim
wget "https://github.com/valheimPlus/ValheimPlus/releases/download/latest/UnixServer.zip"
unzip UnixServer.zip
```

---

# **Final Words**

You now have a fully functional Valheim server! If you prefer an easier option, consider renting a pre-configured Valheim server from us.

[Check out our Valheim Game Servers.](https://deinserverhost.de/valheim-server-mieten)

